CreatePasskeyResponse class

Represents the response from passkey creation

Constructors

CreatePasskeyResponse({required String clientDataJSON, required String attestationObject, List<String?>? transports, String? authenticatorData, int? publicKeyAlgorithm, String? publicKey})

Properties

attestationObject String
Attestation object
getter/setter pair
authenticatorData String?
Authenticator data
getter/setter pair
clientDataJSON String
Client data JSON
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
publicKey String?
Public key
getter/setter pair
publicKeyAlgorithm int?
Public key algorithm identifier
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transports List<String?>?
List of transport methods
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) CreatePasskeyResponse