PrfExtensionInput class

WebAuthn PRF Extension Input payload The WebAuthn specification stipulates eval dictionaries contain first (and optionally second) salt strings. The underlying platform APIs (like Android Credential Manager) expect these Strings to be Base64URL-encoded representations of a 32-byte ArrayBuffer.

Constructors

PrfExtensionInput({Map<String?, String?>? eval})

Properties

eval Map<String?, String?>?
The dictionary structure containing salts ('first' and optionally 'second')
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) PrfExtensionInput