RegisterGenerateOptionAuthenticatorSelection class

Represents authenticator selection criteria

Constructors

RegisterGenerateOptionAuthenticatorSelection({required String residentKey, required String userVerification, required bool requireResidentKey, String authenticatorAttachment = 'platform'})

Properties

authenticatorAttachment String
Authenticator attachment preference
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
requireResidentKey bool
Whether resident key is required
getter/setter pair
residentKey String
Resident key requirement
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVerification String
User verification requirement
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override