RegisterGenerateOptionUser class
Represents user information for registration
Constructors
- RegisterGenerateOptionUser({required String id, required String name, String displayName = ''})
Properties
- displayName ↔ String
-
Display name (defaults to empty string)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
User identifier
getter/setter pair
- name ↔ String
-
User name
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → RegisterGenerateOptionUser