pigeons/messages.g library
Classes
- AuthGenerateOptionAllowCredential
- Represents an allowed credential for authentication
- AuthGenerateOptionExtension
- Represents extensions for authentication options
- AuthGenerateOptionResponseData
- Represents the response data for authentication generation options
- AuthPasskeyExtensionResult
- Represents client extension results for passkey authentication
- AuthVerifyResponse
- Represents the response data for authentication verification
- CreatePasskeyExtension
- Represents client extension results for passkey creation
- CreatePasskeyExtensionProps
- Represents credential properties extension
- CreatePasskeyResponse
- Represents the response from passkey creation
- CreatePasskeyResponseData
- Represents the response data for creating a passkey
- GetPasskeyAuthenticationResponse
- Represents the authentication response from passkey
- GetPasskeyAuthenticationResponseData
- Represents the response data for passkey authentication
- LargeBlobExtensionAuthInput
- LargeBlob extension input for authentication Supports reading or writing blob data (mutually exclusive per WebAuthn spec)
- LargeBlobExtensionAuthOutput
- LargeBlob extension output for authentication Contains the read blob data or write success status
- LargeBlobExtensionRegistrationInput
- LargeBlob extension input for registration Indicates whether the authenticator should support largeBlob storage
- LargeBlobExtensionRegistrationOutput
- LargeBlob extension output for registration Indicates whether the authenticator supports largeBlob storage
- PasskeyException
- Represents a standardized passkey exception that can be thrown across platforms
- PasskeyHostApi
- Host API for passkey operations from Flutter to native platforms
- PrfExtensionInput
-
WebAuthn PRF Extension Input payload
The WebAuthn specification stipulates eval dictionaries contain
first(and optionallysecond) salt strings. The underlying platform APIs (like Android Credential Manager) expect these Strings to be Base64URL-encoded representations of a 32-byte ArrayBuffer. - PrfExtensionOutput
- Represents PRF extension output results
- RegisterGenerateOptionAuthenticatorSelection
- Represents authenticator selection criteria
- RegisterGenerateOptionData
- Represents the data for generating registration options
- RegisterGenerateOptionExcludeCredential
- Represents a credential to exclude from registration
- RegisterGenerateOptionExtension
- Represents extensions for registration
- RegisterGenerateOptionPublicKeyParams
- Represents public key credential parameters
- RegisterGenerateOptionRp
- Represents relying party information for registration
- RegisterGenerateOptionUser
- Represents user information for registration
- RegisterVerifyResponse
- Represents the response data for registration verification
- User
- Represents user information
Enums
- PasskeyErrorType
- Predefined error types for consistent error handling across platforms