AuthGenerateOptionResponseData class
Represents the response data for authentication generation options
- Available extensions
Constructors
-
AuthGenerateOptionResponseData({required String rpId, required String challenge, required List<
AuthGenerateOptionAllowCredential> allowCredentials, required int timeout, required String userVerification, List<String?> ? hints, AuthGenerateOptionExtension? extensions})
Properties
-
allowCredentials
↔ List<
AuthGenerateOptionAllowCredential> -
List of allowed credentials
getter/setter pair
- challenge ↔ String
-
The challenge string
getter/setter pair
- extensions ↔ AuthGenerateOptionExtension?
-
Extensions for authentication
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
hints
↔ List<
String?> ? -
Hints for the authenticator
getter/setter pair
- rpId ↔ String
-
The relying party identifier
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ int
-
Timeout value in milliseconds
getter/setter pair
- userVerification ↔ String
-
User verification requirement
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Available on AuthGenerateOptionResponseData, provided by the AuthGenerateOptionResponseDataExtension extension
Converts AuthGenerateOptionResponseData to JSON Map -
toJsonString(
) → String -
Available on AuthGenerateOptionResponseData, provided by the AuthGenerateOptionResponseDataExtension extension
Converts AuthGenerateOptionResponseData to JSON string -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → AuthGenerateOptionResponseData