GetPasskeyAuthenticationResponseData class
Represents the response data for passkey authentication
Constructors
- GetPasskeyAuthenticationResponseData({String? authenticatorAttachment, required String id, required String rawId, required GetPasskeyAuthenticationResponse response, required String type, AuthPasskeyExtensionResult? clientExtensionResults, String username = 'username'})
Properties
- authenticatorAttachment ↔ String?
-
Authenticator attachment type
getter/setter pair
- clientExtensionResults ↔ AuthPasskeyExtensionResult?
-
Client extension results
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
Credential identifier
getter/setter pair
- rawId ↔ String
-
Raw identifier
getter/setter pair
- response ↔ GetPasskeyAuthenticationResponse
-
Authentication response data
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
Type of credential
getter/setter pair
- username ↔ String
-
Username associated with the passkey
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → GetPasskeyAuthenticationResponseData