LargeBlobExtensionAuthOutput class
LargeBlob extension output for authentication Contains the read blob data or write success status
Constructors
- LargeBlobExtensionAuthOutput({Uint8List? blob, bool? written})
Properties
- blob ↔ Uint8List?
-
The retrieved blob data (when read was requested)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- written ↔ bool?
-
Whether the write operation succeeded (when write was requested)
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → LargeBlobExtensionAuthOutput